@@ -34,8 +34,8 @@ public:
 
     static TransportPluginManager *self();
 
-    MailTransport::TransportAbstractPlugin *plugin(const QString &identifier);
-    QVector<MailTransport::TransportAbstractPlugin *> pluginsList() const;
+    Q_REQUIRED_RESULT MailTransport::TransportAbstractPlugin *plugin(const QString &identifier);
+    Q_REQUIRED_RESULT QVector<MailTransport::TransportAbstractPlugin *> pluginsList() const;
 
 Q_SIGNALS:
     void updatePluginList();
