@@ -24,9 +24,9 @@
 
 #include <mailtransportakonadi_export.h>
 
-#include <QtCore/QSharedDataPointer>
-#include <QtCore/QVariant>
-#include <QtCore/QVector>
+#include <QSharedDataPointer>
+#include <QVariant>
+#include <QVector>
 #include <attribute.h>
 
 namespace MailTransport {
@@ -120,7 +120,7 @@ public:
     /**
      * Destroys the sent action attribute.
      */
-    virtual ~SentActionAttribute();
+    ~SentActionAttribute() override;
 
     /**
      * Adds a new action to the attribute.
@@ -136,10 +136,10 @@ public:
     Action::List actions() const;
 
     /* reimpl */
-    SentActionAttribute *clone() const Q_DECL_OVERRIDE;
-    QByteArray type() const Q_DECL_OVERRIDE;
-    QByteArray serialized() const Q_DECL_OVERRIDE;
-    void deserialize(const QByteArray &data) Q_DECL_OVERRIDE;
+    SentActionAttribute *clone() const override;
+    QByteArray type() const override;
+    QByteArray serialized() const override;
+    void deserialize(const QByteArray &data) override;
 
 private:
     //@cond PRIVATE
